CLI
===

**finagg**'s command-line interface (CLI). A selection of tools for aggregating
popular data and features from each of the supported APIs.

General
-------

.. program-output:: finagg install --help

BEA
---

.. program-output:: finagg bea install --help

FRED
----

.. program-output:: finagg fred install --help

Popular Indices
---------------

.. program-output:: finagg indices install --help

SEC
---

.. program-output:: finagg sec install --help

Yahoo! Finance
--------------

.. program-output:: finagg yfinance install --help

.. program-output:: finagg yfinance update --help

Fundamental Features
--------------------

.. program-output:: finagg fundam install --help
